/*
    Copyright (c) 2014 digitalSTROM AG, Zurich, Switzerland

    Author: Sergey 'Jin' Bostandzhyan <jin@dev.digitalstrom.org>

    This file is part of dS485p, imported from libdSvDC.

    dS485p is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    dS485p is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with digitalSTROM Server. If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef __DS485P_AVAHI_DISCOVERY_H__
#define __DS485P_AVAHI_DISCOVERY_H__

#ifdef HAVE_AVAHI

#include <stdint.h>
#include <stdbool.h>

#include <avahi-client/client.h>
#include <avahi-client/lookup.h>

#include <avahi-common/simple-watch.h>
#include <avahi-common/malloc.h>
#include <avahi-common/error.h>

/* definition dsuid_t */
#include <digitalSTROM/ds485.h>

typedef struct ds485p_avahi_handle {
    AvahiSimplePoll *simple_poll;
    AvahiClient *client;
    /* browser for vdsm */
    AvahiServiceBrowser *browser_vdc;
    /* browser for ds485p */
    AvahiServiceBrowser *browser_ds485;

    bool initialized;
} ds485p_avahi_handle_t;

bool ds485p_avahi_init(ds485p_avahi_handle_t *avahi, int enableDs485d);
void ds485p_avahi_shutdown(ds485p_avahi_handle_t *avahi);

struct ds485_avahi_callbacks {
    void (*bus_discovered)(const char *uri, const char *name,
                           const dsuid_t *dsuid);
    void (*bus_left)(const char *name);
};

#define DISCOVER_DS485D 0x1
int start_discovery(int discover_filter, struct ds485_avahi_callbacks *cb);
void stop_discovery();

#endif//HAVE_AVAHI

#endif//__DS485P_AVAHI_DISCOVERY_H__
